@@ -4,13 +4,32 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::IOLoop::Subprocess;
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
+
+my ($deserialize, $serialize);
 
 sub register {
   my ($self, $app, $options) = @_;
   
   my %subprocess_args = %{$options // {}};
   
+  if (delete $subprocess_args{use_sereal}) {
+    unless (defined $deserialize) {
+      require Sereal::Decoder;
+      Sereal::Decoder->VERSION('3.001');
+      my $deserializer = Sereal::Decoder->new;
+      $deserialize = sub { Sereal::Decoder::sereal_decode_with_object $deserializer, $_[0] };
+    }
+    $subprocess_args{deserialize} = $deserialize;
+    unless (defined $serialize) {
+      require Sereal::Encoder;
+      Sereal::Encoder->VERSION('3.001');
+      my $serializer = Sereal::Encoder->new({freeze_callbacks => 1});
+      $serialize = sub { Sereal::Encoder::sereal_encode_with_object $serializer, $_[0] };
+    }
+    $subprocess_args{serialize} = $serialize;
+  }
+  
   $app->helper(subprocess => sub {
     my ($c, $child, $parent) = @_;
     
@@ -51,20 +70,23 @@ Mojolicious::Plugin::Subprocess - Subprocesses in Mojolicious applications
   };
   
   # or use Sereal as serializer
-  my $encoder = Sereal::Encoder->new;
-  my $decoder = Sereal::Decoder->new;
-  plugin 'Subprocess' => {
-    serialize => sub { $encoder->encode($_[0]) },
-    deserialize => sub { $decoder->decode($_[0]) },
-  };
+  plugin 'Subprocess' => {use_sereal => 1};
 
 =head1 DESCRIPTION
 
 L<Mojolicious::Plugin::Subprocess> is a L<Mojolicious> plugin that adds a
 L</"subprocess"> helper method to your application, which uses
 L<Mojo::IOLoop::Subprocess> to perform computationally expensive operations in
-subprocesses without blocking the event loop. Any options passed to the plugin
-will be used as attributes to build the L<Mojo::IOLoop::Subprocess> object.
+subprocesses without blocking the event loop.
+
+The option C<use_sereal> (requires L<Sereal> version 3.001 or higher) will use
+L<Sereal> for data serialization, which is faster than L<Storable> and supports
+serialization of more reference types such as C<Regexp>. The
+L<Sereal::Encoder/"FREEZE/THAW CALLBACK MECHANISM"> is supported to control
+serialization of blessed objects.
+
+Any other options passed to the plugin will be used as attributes to build the
+L<Mojo::IOLoop::Subprocess> object.
 
 Note that it does not increase the timeout of the connection, so if your forked
 process is going to take a very long time, you might need to increase that
